.. solarenergy documentation master file, created by
   sphinx-quickstart on Sat Oct 10 19:04:36 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to solarenergy's documentation!
=======================================

.. toctree::
   :maxdepth: 4
   :caption: Contents:
   
   solarenergy



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
